@@ -29,12 +29,11 @@ class IPFilterPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    IPFilterPlugin(QObject *parent, const QVariantList &args);
+    IPFilterPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~IPFilterPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
     /// Loads the KT format list filter
     void loadFilters();
